#
# spec file for package blueman
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           blueman
Version:        2.0.4
Release:        1.1
Summary:        GTK+ Bluetooth Manager
License:        GPL-3.0
Group:          System/GUI/GNOME
Url:            https://github.com/blueman-project/blueman
Source:         https://github.com/%{name}-project/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  automake
BuildRequires:  dbus-1-python3-devel
#BuildRequires:  pkgconfig(notify-python)
BuildRequires:  fdupes
BuildRequires:  gnome-icon-theme
# Needed for typelib() - Requires.
BuildRequires:  gobject-introspection
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-Cython
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(pygobject-3.0)
BuildRequires:  pkgconfig(python3)
Requires:       bluez
Requires:       dbus-1-python3
Requires:       gdk-pixbuf-loader-rsvg
Requires:       notification-daemon
Requires:       obex-data-server
Requires:       polkit
Requires:       pulseaudio-utils
Requires:       python3-cairo
Requires:       python3-gobject-Gdk
Requires:       python3-notify2
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%glib2_gsettings_schema_requires

%description
Blueman provides means for controlling the BlueZ API and presenting
Bluetooth operations such as:

    * Connecting to 3G/EDGE/GPRS via dial-up
    * Connecting to/Creating bluetooth networks
    * Connecting to input devices
    * Connecting to audio devices
    * Sending/Receiving/Browsing files via OBEX
    * Pairing

using a graphical user interface.

%package -n thunar-sendto-%{name}
Summary:        A sendto integration for Thunar
Group:          System/GUI/XFCE
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description -n thunar-sendto-%{name}
This package add sendto integration for Thunar.

%lang_package

%prep
%setup -q
sed -i '1s/python.*/python3/' apps/%{name}-*
echo -e 'NotShowIn=KDE;GNOME;' >> data/%{name}.desktop.in
# Remove appindicator support because it breaks system tray
sed -i 's|AppIndicator.py||g' blueman/plugins/applet/Makefile.*
# Fix path for bluetoothd
sed -i 's|%{_sbindir}/bluetoothd|%{_prefix}/lib/bluetooth/bluetoothd|' apps/blueman-report
# Fix non-standard icon names
sed -i 's/gtk-find/edit-find/' data/ui/device-list-widget.ui
sed -i 's/mouse/input-mouse/' blueman/services/Input.py

%build
#NOCONFIGURE=1 ./autogen.sh
autoreconf -fiv
export PYTHON=%{_bindir}/python3
export PYTHON_CFLAGS=-I/usr/include/python%{py3_ver}m
export PYTHON_LIBS=-lpython%{py3_ver}m
export CYTHONEXEC=%{_bindir}/cython-%{py3_ver}
%configure --prefix=%{_prefix} --enable-static=no \
	--enable-polkit --disable-schemas-compile
make %{?_smp_mflags}

%install
%make_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_datadir}/doc/%{name}
%fdupes %{buildroot}%{python3_sitelib}
%fdupes %{buildroot}%{_datadir}/icons/hicolor
%find_lang %{name}
%suse_update_desktop_file -i %{name}-manager

%post
%icon_theme_cache_post
%glib2_gsettings_schema_post

%postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun

%files
%defattr(-,root,root)
%doc CHANGELOG.md COPYING Dependencies.md FAQ README.md
%config %{_sysconfdir}/dbus-1/system.d/org.%{name}.Mechanism.conf
%{_sysconfdir}/xdg/autostart/%{name}.desktop
%{_bindir}/%{name}-*
%{_libexecdir}/%{name}-mechanism
%{_libexecdir}/%{name}-rfcomm-watcher
%{python3_sitelib}/%{name}
%{python3_sitearch}/*%{name}*
%{_datadir}/applications/%{name}-manager.desktop
%{_datadir}/applications/%{name}-adapters.desktop
%{_datadir}/%{name}
%{_datadir}/dbus-1/services/%{name}-applet.service
%{_datadir}/dbus-1/system-services/org.%{name}.Mechanism.service
%{_datadir}/glib-2.0/schemas/org.%{name}.gschema.xml
%{_datadir}/icons/hicolor/*/*/blue*.*
%{_mandir}/man*/%{name}-*%{ext_man}
%{_datadir}/pixmaps/%{name}
%{_datadir}/polkit-1/actions/org.%{name}.policy

%files -n thunar-sendto-%{name}
%defattr(-,root,root)
%dir %{_datadir}/Thunar
%dir %{_datadir}/Thunar/sendto
%{_datadir}/Thunar/sendto/thunar-sendto-%{name}.desktop

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Fri Apr 28 2017 jengelh@inai.de
- Ensure neutrality of description
* Thu Apr 27 2017 bosim@opensuse.org
- ran spec-cleaner
* Thu Apr 27 2017 meissner@suse.com
- removed rpmlintrc
* Wed Apr  6 2016 and.november@opensuse.org
- update to version 2.0.4
* Fri Jan  1 2016 and.november@opensuse.org
- update to version 2.0.3
* Thu Dec 17 2015 and.november@opensuse.org
- update to version 2.0.2
* Fri Oct  9 2015 and.november@opensuse.org
- update to version 2.0.1
* Sun Jun 14 2015 and.november@opensuse.org
- build with python3
